pub fn init_block_entities()Expand description
Initializes the global block entity registry.
This should be called after the main registry is frozen. Repeated calls are a no-op.
pub fn init_block_entities()Initializes the global block entity registry.
This should be called after the main registry is frozen. Repeated calls are a no-op.